from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, Array, String, Int, File

Cs_Count_V0_1_0 = CommandToolBuilder(tool="cs_count", base_command=["cs", "count"], inputs=[ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Suppress all warning messages. Cannot use with '-v'.")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="Increase verbosity. With '-v', show every warning.\nWith '-vv', turn warnings into exceptions. Cannot use\nwith '-q'. (Default: show each type of warning once)")), ToolInput(tag="in_count_files", input_type=Array(t=String(), optional=True), prefix="--count_files", doc=InputDocumentation(doc="One or more count or alignment file(s) from a single\nsample or set of samples to be pooled.")), ToolInput(tag="in_count_file_format", input_type=String(optional=True), prefix="--countfile_format", doc=InputDocumentation(doc="Format of file containing alignments or counts\n(Default: BAM)")), ToolInput(tag="in_sum", input_type=String(optional=True), prefix="--sum", doc=InputDocumentation(doc="Sum used in normalization of counts and RPKM/RPNT\ncalculations (Default: total mapped reads/counts in\ndataset)")), ToolInput(tag="in_min_length", input_type=Int(optional=True), prefix="--min_length", doc=InputDocumentation(doc="Minimum read length required to be included (BAM &\nbowtie files only. Default: 25)")), ToolInput(tag="in_max_length", input_type=Int(optional=True), prefix="--max_length", doc=InputDocumentation(doc="Maximum read length permitted to be included (BAM &\nbowtie files only. Default: 100)")), ToolInput(tag="in_maxmem", input_type=Int(optional=True), prefix="--maxmem", doc=InputDocumentation(doc="Maximum desired memory footprint in MB to devote to\nBigBed/BigWig files. May be exceeded by large queries.\n(Default: 0, No maximum)")), ToolInput(tag="in_big_genome", input_type=Boolean(optional=True), prefix="--big_genome", doc=InputDocumentation(doc="Use slower but memory-efficient implementation for big\ngenomes or for memory-limited computers. For wiggle &\nbowtie files only.")), ToolInput(tag="in_five_prime_variable", input_type=Boolean(optional=True), prefix="--fiveprime_variable", doc=InputDocumentation(doc="Map read alignment to a variable offset from 5'\nposition of read, with offset determined by read\nlength. Requires `--offset` below")), ToolInput(tag="in_five_prime", input_type=Boolean(optional=True), prefix="--fiveprime", doc=InputDocumentation(doc="Map read alignment to 5' position.")), ToolInput(tag="in_three_prime", input_type=Boolean(optional=True), prefix="--threeprime", doc=InputDocumentation(doc="Map read alignment to 3' position")), ToolInput(tag="in_center", input_type=Boolean(optional=True), prefix="--center", doc=InputDocumentation(doc="Subtract N positions from each end of read, and add\n1/(length-N), to each remaining position, where N is\nspecified by `--nibble`")), ToolInput(tag="in_offset", input_type=Int(optional=True), prefix="--offset", doc=InputDocumentation(doc="For `--fiveprime` or `--threeprime`, provide an\ninteger representing the offset into the read,\nstarting from either the 5' or 3' end, at which data\nshould be plotted. For `--fiveprime_variable`, provide\nthe filename of a two-column tab-delimited text file,\nin which first column represents read length or the\nspecial keyword `'default'`, and the second column\nrepresents the offset from the five prime end of that\nread length at which the read should be mapped.\n(Default: 0)")), ToolInput(tag="in_nibble", input_type=Int(optional=True), prefix="--nibble", doc=InputDocumentation(doc="For use with `--center` only. nt to remove from each\nend of read before mapping (Default: 0)\n")), ToolInput(tag="in_file_dot_positions", input_type=File(), position=0, doc=InputDocumentation(doc="File assigning positions to genes or transcripts (made\nusing 'generate' subcommand)")), ToolInput(tag="in_out_base", input_type=String(), position=1, doc=InputDocumentation(doc="Basename for output files"))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Cs_Count_V0_1_0().translate("wdl", allow_empty_container=True)

